CLI
============

The :py:mod:`cli <curveball.scripts.cli>` module implements a command line interface that allows to interact with Curveball
through a command line or terminal, without any knowledge in Python programming.

The :doc:`tutorial` includes a complete walkthrough on using the CLI to analyse growth cruves data.

Members
-------

.. automodule:: curveball.scripts.cli
   :members:
